@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,6 +12,11 @@
 #include <QStandardPaths>
 #include <QTest>
 
+// taken from tst_qstandardpaths
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC) && !defined(Q_OS_BLACKBERRY) && !defined(Q_OS_ANDROID)
+#define Q_XDG_PLATFORM
+#endif
+
 Q_DECLARE_METATYPE(SieveEditorUtil::SieveServerConfig)
 ImportImapSettingsAkonadiCheckJobTest::ImportImapSettingsAkonadiCheckJobTest(QObject *parent)
     : QObject(parent)
@@ -23,6 +28,11 @@ ImportImapSettingsAkonadiCheckJobTest::~ImportImapSettingsAkonadiCheckJobTest()
 
 void ImportImapSettingsAkonadiCheckJobTest::initTestCase()
 {
+#ifndef Q_XDG_PLATFORM
+    // We need to make changes to a global dir without messing up the system
+    QSKIP("This test requires XDG_DATA_DIRS");
+#endif
+
     QStandardPaths::setTestModeEnabled(true);
 }
 
